Electrum-merchant
-----------------
This is an add-on to Electrum wallet, which allows Electrum to function as a payment service.
Full documentation is available on: http://docs.electrum.org/en/latest/merchant.html
